==> ejc-probuilddiary-api-3.0.0-20220922.033836-40-sources.jar: com/ejianc/business/probuilddiary/construct/vo/ConstructAreaVO.java <==
package com.ejianc.business.probuilddiary.construct.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 施工区域设置
 * 
 * @author generator
 * 
 */
public class ConstructAreaVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Date commitDate; // 提交日期
    private String commitUserName; // 提交人名称
    private Long commitUserId; // 提交人id
    private String commitUserCode; // 提交人账号
    private Date effectiveDate; // 生效日期
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private String billStateName; // 单据状态名称
    private Long employeeId; // 编制人id
    private String employeeName; // 编制人名称
    private Long orgId; // 项目所属项目部ID
    private String orgCode; // 项目所属项目部编码
    private String orgName; // 项目所属项目部名称
    private Long parentOrgId; // 项目所属上级组织ID
    private String parentOrgCode; // 项目所属上级组织编码
    private String parentOrgName; // 项目所属上级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date staffingDate; // 编制日期
    private String memo; // 备注
    private String billStateStr;


    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    private List<ConstructAreaDetailVO> detailList = new ArrayList<>(); // 施工区域 详情表

    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }

    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getStaffingDate() {
        return staffingDate;
    }

    public void setStaffingDate(Date staffingDate) {
        this.staffingDate = staffingDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
     public List<ConstructAreaDetailVO> getDetailList() {
        return detailList;
     }

     public void setDetailList(List<ConstructAreaDetailVO> detailList) {
        this.detailList = detailList;
     }
}

==> ejc-probuilddiary-api-3.0.0-20221008.094809-98-sources.jar: com/ejianc/business/probuilddiary/construct/vo/ConstructAreaVO.java <==
package com.ejianc.business.probuilddiary.construct.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 施工区域设置
 * 
 * @author generator
 * 
 */
public class ConstructAreaVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Date commitDate; // 提交日期
    private String commitUserName; // 提交人名称
    private Long commitUserId; // 提交人id
    private String commitUserCode; // 提交人账号
    private Date effectiveDate; // 生效日期
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private String billStateName; // 单据状态名称
    private Long employeeId; // 编制人id
    private String employeeName; // 编制人名称
    private Long orgId; // 项目所属项目部ID
    private String orgCode; // 项目所属项目部编码
    private String orgName; // 项目所属项目部名称
    private Long parentOrgId; // 项目所属上级组织ID
    private String parentOrgCode; // 项目所属上级组织编码
    private String parentOrgName; // 项目所属上级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date staffingDate; // 编制日期
    private String memo; // 备注
    private String billStateStr;
    private Integer modifyFlag; //单据生效后修改状态：0-未修改，1-已修改

    private String operate; //编辑标识，此标识为：update时，返回详情至前端时将billState设置为0使其可编辑


    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    private List<ConstructAreaDetailVO> detailList = new ArrayList<>(); // 施工区域 详情表

    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }

    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getStaffingDate() {
        return staffingDate;
    }

    public void setStaffingDate(Date staffingDate) {
        this.staffingDate = staffingDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
     public List<ConstructAreaDetailVO> getDetailList() {
        return detailList;
     }

     public void setDetailList(List<ConstructAreaDetailVO> detailList) {
        this.detailList = detailList;
     }

    public String getOperate() {
        return operate;
    }

    public void setOperate(String operate) {
        this.operate = operate;
    }

    public Integer getModifyFlag() {
        return modifyFlag;
    }

    public void setModifyFlag(Integer modifyFlag) {
        this.modifyFlag = modifyFlag;
    }
}
